@@ -1,5 +1,6 @@
 
 test_that("utils functions work", {
+  skip_on_cran()
 
   # capture_requests({
   #
@@ -12,14 +13,20 @@ test_that("utils functions work", {
   # })
 
 
-  with_mock_api({
-    res <- valid_dates()
-    expect_is(res, "data.frame")
+  # with_mock_api({
+  #   res <- valid_dates()
+  #   expect_is(res, "data.frame")
+  #
+  #
+  #   symbols <- available_symbols()
+  #   expect_is(symbols, "character")
+  # })
 
+res <- valid_dates()
+expect_is(res, "data.frame")
 
-    symbols <- available_symbols()
-    expect_is(symbols, "character")
-  })
+symbols <- available_symbols()
+expect_is(symbols, "character")
 
   expect_false(date_check("hello"))
 })
